@@ -92,14 +92,14 @@ public class XMLJUnitTest extends JUnitTest {
 
         // ファイルが存在しない場合はエラー。
         if (!pathelem.exists()) {
-            throw new BuildException("could not find path \"" + path + "\".");
+            throw new BuildException("cannot find path \"" + path + "\".");
         }
 
         // 絶対パスに変換。
         try {
             path = pathelem.getCanonicalPath();
         } catch (IOException e) {
-            throw new BuildException("could not get canonical path \"" + path
+            throw new BuildException("cannot get canonical path \"" + path
                     + "\".", e);
         }
 
