@@ -9,6 +9,7 @@ import java.lang.reflect.Modifier;
 import java.lang.reflect.Proxy;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.List;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
@@ -155,6 +156,37 @@ public class ObjectUtils {
         return obj;
     }
 
+    /**
+     * プリミティブラッパーを取得する。
+     * 
+     * @param type 型
+     * @return プリミティブラッパー
+     */
+    public static Class getPrimitiveWrapperClass(String type) {
+        Class clazz = null;
+
+        // ラッパーを取得する。
+        if ("bool".equals(type) || "boolean".equals(type)) {
+            clazz = Boolean.class;
+        } else if ("byte".equals(type)) {
+            clazz = Byte.class;
+        } else if ("char".equals(type) || "character".equals(type)) {
+            clazz = Character.class;
+        } else if ("short".equals(type)) {
+            clazz = Short.class;
+        } else if ("int".equals(type) || "integer".equals(type)) {
+            clazz = Integer.class;
+        } else if ("long".equals(type)) {
+            clazz = Long.class;
+        } else if ("float".equals(type)) {
+            clazz = Float.class;
+        } else if ("double".equals(type)) {
+            clazz = Double.class;
+        }
+
+        return clazz;
+    }
+
     /**
      * インスタンスを取得する。
      * 
@@ -180,13 +212,11 @@ public class ObjectUtils {
     public static Object getInstance(Class clazz, Class[] classes,
             Object[] arguments) {
         try {
-            Constructor constructor = clazz.getDeclaredConstructor(classes);
+            Constructor constructor = getConstructor(clazz, classes);
             constructor.setAccessible(true);
             return constructor.newInstance(arguments);
         } catch (SecurityException e) {
             throw new BodyBuilderException(e);
-        } catch (NoSuchMethodException e) {
-            throw new BodyBuilderException(e);
         } catch (IllegalArgumentException e) {
             throw new BodyBuilderException(e);
         } catch (InstantiationException e) {
@@ -198,6 +228,59 @@ public class ObjectUtils {
         }
     }
 
+    /**
+     * コンストラクタを取得する。
+     * 
+     * @param clazz クラス
+     * @param types パラメータの型
+     * @return コンストラクタ
+     */
+    public static Constructor getConstructor(Class clazz, Class[] types) {
+        try {
+            if (types == null || types.length < 1) {
+                return clazz.getConstructor(new Class[0]);
+            }
+
+            Constructor constructor = null;
+            Constructor[] constructors = clazz.getDeclaredConstructors();
+
+            for (int i = 0; i < constructors.length; i++) {
+                Class[] classes = constructors[i].getParameterTypes();
+
+                if (classes.length != types.length) {
+                    continue;
+                }
+
+                boolean equalsTypes = true;
+
+                for (int j = 0; j < types.length; j++) {
+                    if (!instance_of(types[j], classes[j])) {
+                        equalsTypes = false;
+                        break;
+                    }
+                }
+
+                if (equalsTypes) {
+                    constructor = constructors[i];
+                    break;
+                }
+            }
+
+            if (constructor == null) {
+                throw new BodyBuilderException("cannot find constructor "
+                        + Arrays.asList(types) + ".");
+            }
+
+            return constructor;
+        } catch (SecurityException e) {
+            throw new BodyBuilderException("cannot find constructor "
+                    + Arrays.asList(types) + ".", e);
+        } catch (NoSuchMethodException e) {
+            throw new BodyBuilderException("cannot find constructor "
+                    + Arrays.asList(types) + ".", e);
+        }
+    }
+
     /////////////////////////////////////////////////////////////////
     // array method
 
@@ -544,35 +627,39 @@ public class ObjectUtils {
      */
     public static List getClassNames(Class clazz, boolean isReverse) {
         List classNames = new ArrayList();
-        Class cls = clazz;
 
-        // プリミティブ型の場合
         if (clazz.isPrimitive()) {
+            // プリミティブ型の場合
+            classNames.add(clazz.getName());
             classNames.add("primitive");
-            return classNames;
-        }
-
-        // 配列の場合
-        if (clazz.isArray()) {
+        } else if (clazz.isArray()) {
+            // 配列の場合
+            String name = clazz.getComponentType().getName() + "[]";
+            classNames.add(getArrayClassName(name));
+            classNames.add(name);
             classNames.add("array");
-            return classNames;
+        } else {
+            // それ以外の場合
+            final String objectClassName = Object.class.getName();
+            List interfaceNames = new ArrayList();
+            Class cls = clazz;
+
+            // 親クラス名を取得。
+            while (cls != null && !cls.getName().equals(objectClassName)) {
+                classNames.add(cls.getName());
+                // インターフェイス名を取得。
+                addInterfaceNames(cls, interfaceNames);
+                cls = cls.getSuperclass();
+            }
+
+            // インターフェース名をリストに追加。
+            classNames.addAll(interfaceNames);
         }
 
-        // それ以外の場合
-        final String objectClassName = Object.class.getName();
-        List interfaceNames = new ArrayList();
-
-        // 親クラス名を取得。
-        while (!cls.getName().equals(objectClassName)) {
-            classNames.add(cls.getName());
-            // インターフェイス名を取得。
-            addInterfaceNames(cls, interfaceNames);
-            cls = cls.getSuperclass();
+        if (isReverse) {
+            Collections.reverse(classNames);
         }
 
-        // インターフェース名をリストに追加。
-        classNames.addAll(interfaceNames);
-
         return classNames;
     }
 
@@ -623,31 +710,63 @@ public class ObjectUtils {
      * メソッドを取得する。
      * 
      * @param clazz クラス
-     * @param name メソッド名
-     * @param classes 引数のクラス
+     * @param types パラメータの型
      * @return メソッド
      */
-    public static Method getMethod(Class clazz, String name, Class[] classes) {
+    public static Method getMethod(Class clazz, String name, Class[] types) {
         try {
-            Method method = null;
+            if (types == null || types.length < 1) {
+                return clazz.getMethod(name, new Class[0]);
+            }
 
-            try {
-                // publicメソッド(スパークラスを含む)を取得。
-                method = clazz.getMethod(name, classes);
-            } catch (NoSuchMethodException e) {
-                // public以外のメソッドを取得。
-                method = clazz.getDeclaredMethod(name, classes);
+            Method method = null;
+            Method[] pmethods = clazz.getMethods();
+            Method[] dmethods = clazz.getDeclaredMethods();
+            Method[] methods = new Method[pmethods.length + dmethods.length];
+            System.arraycopy(pmethods, 0, methods, 0, pmethods.length);
+            System.arraycopy(dmethods, 0, methods, pmethods.length,
+                    dmethods.length);
+
+            for (int i = 0; i < methods.length; i++) {
+                if (!methods[i].getName().equals(name)) {
+                    continue;
+                }
+
+                Class[] classes = methods[i].getParameterTypes();
+
+                if (classes.length != types.length) {
+                    continue;
+                }
+
+                boolean equalsTypes = true;
+
+                for (int j = 0; j < types.length; j++) {
+                    if (!instance_of(types[j], classes[j])) {
+                        equalsTypes = false;
+                        break;
+                    }
+                }
+
+                if (equalsTypes) {
+                    method = methods[i];
+                    break;
+                }
+            }
+
+            if (method == null) {
+                throw new BodyBuilderException("cannot find method '" + name
+                        + "' as '" + Arrays.asList(types) + "'");
             }
 
             return method;
         } catch (SecurityException e) {
             throw new BodyBuilderException("cannot get method '" + name + " "
-                    + Arrays.asList(classes) + "' as '" + clazz.getName()
-                    + "'.", e);
+                    + Arrays.asList(types) + "' at '" + clazz.getName() + "'.",
+                    e);
         } catch (NoSuchMethodException e) {
             throw new BodyBuilderException("cannot get method '" + name + " "
-                    + Arrays.asList(classes) + "' as '" + clazz.getName()
-                    + "'.", e);
+                    + Arrays.asList(types) + "' at '" + clazz.getName() + "'.",
+                    e);
         }
     }
 
@@ -717,16 +836,16 @@ public class ObjectUtils {
             return method.invoke(object, arguments);
         } catch (SecurityException e) {
             throw new BodyBuilderException("cannot invole method '"
-                    + method.getName() + "' as '" + object + "'.", e);
+                    + method.getName() + "' at '" + object + "'.", e);
         } catch (IllegalArgumentException e) {
             throw new BodyBuilderException("cannot invole method '"
-                    + method.getName() + "' as '" + object + "'.", e);
+                    + method.getName() + "' at '" + object + "'.", e);
         } catch (IllegalAccessException e) {
             throw new BodyBuilderException("cannot invole method '"
-                    + method.getName() + "' as '" + object + "'.", e);
+                    + method.getName() + "' at '" + object + "'.", e);
         } catch (InvocationTargetException e) {
             throw new BodyBuilderException("cannot invole method '"
-                    + method.getName() + "' as '" + object + "'.", e);
+                    + method.getName() + "' at '" + object + "'.", e);
         }
     }
 
@@ -818,8 +937,17 @@ public class ObjectUtils {
      * @return インスタンスの場合はtrue
      */
     public static boolean instance_of(Class clazz, String type) {
-        List classes = getClassNames(clazz);
-        return classes.contains(type);
+        if (isPrimitive(type)) {
+            if (clazz.isPrimitive()) {
+                return clazz.getName().equals(type);
+            } else {
+                Class wrapper = getPrimitiveWrapperClass(type);
+                return wrapper.getName().equals(clazz.getName());
+            }
+        } else {
+            List classes = getClassNames(clazz);
+            return classes.contains(type);
+        }
     }
 
     /**
@@ -841,8 +969,11 @@ public class ObjectUtils {
      * @return インスタンスの場合はtrue
      */
     public static boolean instance_of(Object obj, String type) {
-        List classes = getClassNames(obj);
-        return classes.contains(type);
+        if (obj == null) {
+            return false;
+        } else {
+            return instance_of(obj.getClass(), type);
+        }
     }
 
     /**
